@@ -1,7 +1,7 @@
 #!/usr/bin/perl
-# DocumentId:	$Id: debarchiver.pl 1971 2005-01-01 19:09:29Z ola $
+# DocumentId:	$Id: debarchiver.pl 1978 2005-01-10 20:53:29Z ola $
 # Author:	$Author: ola $
-# Date:		$Date: 2005-01-01 20:09:29 +0100 (Sat, 01 Jan 2005) $
+# Date:		$Date: 2005-01-10 21:53:29 +0100 (mån, 10 jan 2005) $
 # Version:	$Revision: 1.49 $
 # Summary:
 #	This program reads a config file, traverse through all .changes files
@@ -1653,7 +1653,7 @@ debarchiver [options]
 
 =head1 DESCRIPTION
 
-The debian archiver is a tool that installs debian packages into a file structure suitable for apt-get, dselect and similar tools to use for updating the installed debian system. It is ment to be used by local administrators that needs special packages, or tweaked versions to ease administration.
+The debian archiver is a tool that installs debian packages into a file structure suitable for apt-get, dselect and similar tools to use for updating the installed debian system. It is meant to be used by local administrators that needs special packages, or tweaked versions to ease administration.
 
 The file structure is based on the potato file structure and does not support package pools. This may be implemented later, but is not high priority.
 
@@ -1691,7 +1691,7 @@ The remove command to use, default $rmcmd. This can be used to move away the old
 
 =item B<--instcmd>
 
-DEPRICATED!
+DEPRECATED!
 
 =item B<-d | --dest | --destdir> dir
 
@@ -1727,15 +1727,15 @@ The criteria for which binary packages that should be installed even if it does
  
 =item B<-o | --addoverride>
 
-Automaticly add new packages to the override file.
+Automatically add new packages to the override file.
 
 =item B<--autoscanpackages>
 
-Automaticly run dpkg-scanpackages after all new packages are installed.
+Automatically run dpkg-scanpackages after all new packages are installed.
 
 =item B<--autoscansources>
 
-Automaticly run dpkg-scansources after all new packages are installed.
+Automatically run dpkg-scansources after all new packages are installed.
 
 =item B<-a | --autoscan>
 
@@ -1807,7 +1807,7 @@ The lockfile to use, default $lockfile.
 
 =item B<@mailtos>
 
-An array of strings that should be mailed to. If the string contains en email address that one is used. If it contains an incomplete email address, i.e. @hostname, the username owning the file is used @ the hostname specified. If no @ character is found in the string, it is considered as a field in the.changes file. Such a field can for example be Maintainer or Uploaders.
+An array of strings that should be mailed to. If the string contains an email address that one is used. If it contains an incomplete email address, i.e. @hostname, the username owning the file is used @ the hostname specified. If no @ character is found in the string, it is considered as a field in the .changes file. Such a field can for example be Maintainer or Uploaders.
 
 =item B<%release>
 
@@ -1819,7 +1819,7 @@ There are two ways to generate the indexes that B<apt-get> relies on.
 
 Using B<--autoscanpackages>, B<--autoscansources>, or B<--autoscan> will use B<dpkg-scanpackages> and B<dpkg-scansources>.  This will generate the Packages and Sources files, but will not generate Contents files and can be slow with a large repository.
 
-Alternately, the B<--index> I<config> option will call B<apt-ftparchive> to index the package tree.  B<apt-ftparchive> can also generate Contents files (for use with B<apt-file>), and can optionally use a cache of package information to speed up multiple runs.  The B<apt-ftparchive> configuration file will be generated automatically. This is however not fully tested.
+Alternatively, the B<--index> I<config> option will call B<apt-ftparchive> to index the package tree.  B<apt-ftparchive> can also generate Contents files (for use with B<apt-file>), and can optionally use a cache of package information to speed up multiple runs.  The B<apt-ftparchive> configuration file will be generated automatically. This is however not fully tested.
 
 You should use either B<--autoscanpackages> and B<--autoscansources> or B<--index>, not both, as they both do basically the same thing.
 
